@@ -8,19 +8,23 @@ class Filesystem(Plugable):
         self._history = []
 
     @abstractmethod
-    def get_filename(self, *args) -> str:
-        pass
+    def get_filename(self, path, base=None) -> str:
+        raise NotImplementedError
 
     @abstractmethod
     def _open(self, filename: str) -> BinaryIO:
-        pass
+        raise NotImplementedError
 
     @abstractmethod
     def exists(self, filename: str) -> bool:
-        pass
+        raise NotImplementedError
+
+    @abstractmethod
+    def get_dir_name(self, filename) -> str:
+        raise NotImplementedError
 
     def canonicalise(self, relative_filename: str):
-        absolute_fn = self.get_filename(relative_filename)
+        absolute_fn = self.get_filename([relative_filename])
         if self.exists(absolute_fn):
             return absolute_fn
         raise FileNotFoundError(absolute_fn)
