@@ -1,13 +1,14 @@
 from typing import TextIO
-from ruamel import yaml
+from ruamel.yaml import YAML
 from .serialisation import TextSerialisation
 
 
 class YamlSerialisation(TextSerialisation, register="yaml"):
     EXTENSION = "yaml"
+    _YAML = YAML(typ="unsafe", pure=True)
 
     def dump(self, datastructure: dict, textstream: TextIO):
-        yaml.dump(datastructure, textstream, yaml.Dumper)
+        self._YAML.dump(datastructure, textstream)
 
     def load(self, textstream: TextIO) -> dict:
-        return yaml.load(textstream, yaml.Loader)
+        return self._YAML.load(textstream)
