@@ -31,27 +31,31 @@ class StanzaHandler(Plugable):
 
     @abstractmethod
     def is_valid(self, new_data) -> bool:
-        pass
+        raise NotImplementedError
 
     @abstractmethod
     def _initialise(self):
-        pass
+        raise NotImplementedError
 
     @abstractmethod
     def _merge(self, stanza_data: dict, new_data):
-        pass
+        raise NotImplementedError
+
+    def cleanup(self):
+        self.filenames = []
+        self._includes = 0
 
 
 class TypedStanzaHandler(StanzaHandler):
     @property
     @abstractmethod
     def _type(self) -> typing.Type:
-        pass
+        raise NotImplementedError
 
     def _initialise(self):
         return self._type()
 
     def is_valid(self, new_data):
-        if isinstance(self, new_data):
+        if isinstance(new_data, self._type):
             return True
         return False
